@@ -41,6 +41,8 @@
 
 #define KCODECS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KCODECS_NO_DEPRECATED) && !defined(KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KCODECS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCODECS_NO_DEPRECATED
-#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57300
+#  define KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54500
 #endif
 #ifdef KCODECS_NO_DEPRECATED_WARNINGS
 #  define KCODECS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCODECS_DEPRECATED_WARNINGS_SINCE KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x57300
+#    define KCODECS_DEPRECATED_WARNINGS_SINCE 0x54500
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KCODECS_DEPRECATED
-#  define KCODECS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCODECS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCODECS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCODECS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -119,21 +121,7 @@
 #else
 #  define KCODECS_DEPRECATED_VERSION_5_56(text)
 #endif
-
-#if KCODECS_DEPRECATED_WARNINGS_SINCE >= 0x56500
-#  define KCODECS_DEPRECATED_VERSION_5_101(text) KCODECS_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KCODECS_DEPRECATED_VERSION_5_101(text)
-#endif
 #define KCODECS_DEPRECATED_VERSION_5(minor, text)      KCODECS_DEPRECATED_VERSION_5_##minor(text)
 #define KCODECS_DEPRECATED_VERSION(major, minor, text) KCODECS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KCODECS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCODECS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KCODECS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCODECS_DEPRECATED_VERSION(major, minor, text)
-#  define KCODECS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCODECS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KCODECS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KCODECS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KCODECS_EXPORT_H */
